import argparse

# sub-command functions
def foo(fargs):
	print(fargs.x * fargs.y)
def bar(args):
	print('((%s))' % args.z)

# create the top-level parser
parser = argparse.ArgumentParser()
subparsers = parser.add_subparsers()

# create the parser for the "foo" command
parser_foo = subparsers.add_parser('foo')
parser_foo.add_argument('-x', type=int, default=1)
parser_foo.add_argument('y', type=float)
parser_foo.set_defaults(func=foo)

# create the parser for the "bar" command
parser_bar = subparsers.add_parser('bar')
parser_bar.add_argument('z')
parser_bar.set_defaults(func=bar)

# parse the args and call whatever function was selected
args = parser.parse_args()
args.func(args)




#!/usr/bin/env python

from Bio import SeqIO


def get_target_seq(args):
    with open(args.target_list, 'r') as fl:
        target_seq_header = fl.read().splitlines()
    target_records = []
    for seq_record in SeqIO.parse(args.input_fasta, "fasta"):
        seq_desc = seq_record.description
        if seq_desc in target_seq_header:
            target_records.append(seq_record)
        seq_id = seq_record.id
        if seq_id in target_seq_header:
            target_records.append(seq_record)
    SeqIO.write(target_records, args.output_fasta, "fasta")
